"use strict";
/**
 * Copyright (c) 2023 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Adam Midlik <midlik@gmail.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomLabelTextVisual = exports.CustomLabelTextParams = void 0;
var tslib_1 = require("tslib");
var text_builder_1 = require("../../../../mol-geo/geometry/text/text-builder");
var complex_visual_1 = require("../../../../mol-repr/structure/complex-visual");
var Original = tslib_1.__importStar(require("../../../../mol-repr/structure/visual/label-text"));
var element_1 = require("../../../../mol-repr/structure/visual/util/element");
var mol_util_1 = require("../../../../mol-util");
var names_1 = require("../../../../mol-util/color/names");
var object_1 = require("../../../../mol-util/object");
var param_definition_1 = require("../../../../mol-util/param-definition");
var label_text_1 = require("../../helpers/label-text");
var param_definition_2 = require("../../helpers/param-definition");
exports.CustomLabelTextParams = tslib_1.__assign(tslib_1.__assign({ items: param_definition_1.ParamDefinition.ObjectList({
        text: param_definition_1.ParamDefinition.Text('¯\\_(ツ)_/¯'),
        position: param_definition_1.ParamDefinition.MappedStatic('selection', {
            x_y_z: param_definition_1.ParamDefinition.Group({
                x: param_definition_1.ParamDefinition.Numeric(0),
                y: param_definition_1.ParamDefinition.Numeric(0),
                z: param_definition_1.ParamDefinition.Numeric(0),
                scale: param_definition_1.ParamDefinition.Numeric(1, { min: 0, max: 20, step: 0.1 })
            }),
            selection: param_definition_1.ParamDefinition.Group({
                label_entity_id: (0, param_definition_2.MaybeStringParamDefinition)(),
                label_asym_id: (0, param_definition_2.MaybeStringParamDefinition)(),
                auth_asym_id: (0, param_definition_2.MaybeStringParamDefinition)(),
                label_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                auth_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                pdbx_PDB_ins_code: (0, param_definition_2.MaybeStringParamDefinition)(),
                /** Minimum label_seq_id (inclusive) */
                beg_label_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(undefined, { description: 'Minimum label_seq_id (inclusive)' }),
                /** Maximum label_seq_id (inclusive) */
                end_label_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                /** Minimum auth_seq_id (inclusive) */
                beg_auth_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                /** Maximum auth_seq_id (inclusive) */
                end_auth_seq_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                /** Atom name like 'CA', 'N', 'O'... */
                label_atom_id: (0, param_definition_2.MaybeStringParamDefinition)(),
                /** Atom name like 'CA', 'N', 'O'... */
                auth_atom_id: (0, param_definition_2.MaybeStringParamDefinition)(),
                /** Element symbol like 'H', 'HE', 'LI', 'BE'... */
                type_symbol: (0, param_definition_2.MaybeStringParamDefinition)(),
                /** Unique atom identifier across conformations (_atom_site.id) */
                atom_id: (0, param_definition_2.MaybeIntegerParamDefinition)(),
                /** 0-base index of the atom in the source data */
                atom_index: (0, param_definition_2.MaybeIntegerParamDefinition)(),
            }),
        }),
    }, function (obj) { return obj.text; }, { isEssential: true }) }, (0, object_1.omitObjectKeys)(Original.LabelTextParams, ['level', 'chainScale', 'residueScale', 'elementScale'])), { borderColor: tslib_1.__assign(tslib_1.__assign({}, Original.LabelTextParams.borderColor), { defaultValue: names_1.ColorNames.black }) });
/** Create "label-text" visual for "Custom Label" representation */
function CustomLabelTextVisual(materialId) {
    return (0, complex_visual_1.ComplexTextVisual)({
        defaultProps: param_definition_1.ParamDefinition.getDefaultValues(exports.CustomLabelTextParams),
        createGeometry: createLabelText,
        createLocationIterator: element_1.ElementIterator.fromStructure,
        getLoci: element_1.getSerialElementLoci,
        eachLocation: element_1.eachSerialElement,
        setUpdateState: function (state, newProps, currentProps) {
            state.createGeometry = !(0, mol_util_1.deepEqual)(newProps.items, currentProps.items);
        }
    }, materialId);
}
exports.CustomLabelTextVisual = CustomLabelTextVisual;
function createLabelText(ctx, structure, theme, props, text) {
    var count = props.items.length;
    var builder = text_builder_1.TextBuilder.create(props, count, count / 2, text);
    for (var _i = 0, _a = props.items; _i < _a.length; _i++) {
        var item = _a[_i];
        switch (item.position.name) {
            case 'x_y_z':
                var scale = item.position.params.scale;
                builder.add(item.text, item.position.params.x, item.position.params.y, item.position.params.z, scale, scale, 0);
                break;
            case 'selection':
                var p = (0, label_text_1.textPropsForSelection)(structure, theme.size.size, item.position.params);
                if (p)
                    builder.add(item.text, p.center[0], p.center[1], p.center[2], p.depth, p.scale, p.group);
                break;
        }
    }
    return builder.getText();
}
