/**
 * Copyright (c) 2023 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Adam Midlik <midlik@gmail.com>
 */
import * as iots from 'io-ts';
import { HexColor } from '../../helpers/utils';
import { ValueFor } from '../generic/params-schema';
/** `format` parameter values for `parse` node in MVS tree */
export declare const ParseFormatT: iots.LiteralC<"pdb" | "bcif" | "mmcif"> | iots.UnionC<[iots.LiteralC<"pdb" | "bcif" | "mmcif">, iots.LiteralC<"pdb" | "bcif" | "mmcif">, ...iots.LiteralC<"pdb" | "bcif" | "mmcif">[]]>;
export type ParseFormatT = ValueFor<typeof ParseFormatT>;
/** `format` parameter values for `parse` node in Molstar tree */
export declare const MolstarParseFormatT: iots.LiteralC<"pdb" | "cif"> | iots.UnionC<[iots.LiteralC<"pdb" | "cif">, iots.LiteralC<"pdb" | "cif">, ...iots.LiteralC<"pdb" | "cif">[]]>;
export type MolstarParseFormatT = ValueFor<typeof MolstarParseFormatT>;
/** `kind` parameter values for `structure` node in MVS tree */
export declare const StructureTypeT: iots.LiteralC<"assembly" | "symmetry" | "model" | "symmetry_mates"> | iots.UnionC<[iots.LiteralC<"assembly" | "symmetry" | "model" | "symmetry_mates">, iots.LiteralC<"assembly" | "symmetry" | "model" | "symmetry_mates">, ...iots.LiteralC<"assembly" | "symmetry" | "model" | "symmetry_mates">[]]>;
/** `selector` parameter values for `component` node in MVS tree */
export declare const ComponentSelectorT: iots.LiteralC<"all" | "polymer" | "water" | "branched" | "ligand" | "ion" | "protein" | "nucleic"> | iots.UnionC<[iots.LiteralC<"all" | "polymer" | "water" | "branched" | "ligand" | "ion" | "protein" | "nucleic">, iots.LiteralC<"all" | "polymer" | "water" | "branched" | "ligand" | "ion" | "protein" | "nucleic">, ...iots.LiteralC<"all" | "polymer" | "water" | "branched" | "ligand" | "ion" | "protein" | "nucleic">[]]>;
/** `selector` parameter values for `component` node in MVS tree */
export declare const ComponentExpressionT: iots.PartialC<{
    label_entity_id: iots.StringC;
    label_asym_id: iots.StringC;
    auth_asym_id: iots.StringC;
    label_seq_id: iots.RefinementC<iots.NumberC, number>;
    auth_seq_id: iots.RefinementC<iots.NumberC, number>;
    pdbx_PDB_ins_code: iots.StringC;
    beg_label_seq_id: iots.RefinementC<iots.NumberC, number>;
    end_label_seq_id: iots.RefinementC<iots.NumberC, number>;
    beg_auth_seq_id: iots.RefinementC<iots.NumberC, number>;
    end_auth_seq_id: iots.RefinementC<iots.NumberC, number>;
    label_atom_id: iots.StringC;
    auth_atom_id: iots.StringC;
    type_symbol: iots.StringC;
    atom_id: iots.RefinementC<iots.NumberC, number>;
    atom_index: iots.RefinementC<iots.NumberC, number>;
}>;
/** `type` parameter values for `representation` node in MVS tree */
export declare const RepresentationTypeT: iots.LiteralC<"surface" | "cartoon" | "ball_and_stick"> | iots.UnionC<[iots.LiteralC<"surface" | "cartoon" | "ball_and_stick">, iots.LiteralC<"surface" | "cartoon" | "ball_and_stick">, ...iots.LiteralC<"surface" | "cartoon" | "ball_and_stick">[]]>;
/** `schema` parameter values for `*_from_uri` and `*_from_source` nodes in MVS tree */
export declare const SchemaT: iots.LiteralC<"atom" | "residue" | "entity" | "chain" | "whole_structure" | "auth_chain" | "auth_residue" | "residue_range" | "auth_residue_range" | "auth_atom" | "all_atomic"> | iots.UnionC<[iots.LiteralC<"atom" | "residue" | "entity" | "chain" | "whole_structure" | "auth_chain" | "auth_residue" | "residue_range" | "auth_residue_range" | "auth_atom" | "all_atomic">, iots.LiteralC<"atom" | "residue" | "entity" | "chain" | "whole_structure" | "auth_chain" | "auth_residue" | "residue_range" | "auth_residue_range" | "auth_atom" | "all_atomic">, ...iots.LiteralC<"atom" | "residue" | "entity" | "chain" | "whole_structure" | "auth_chain" | "auth_residue" | "residue_range" | "auth_residue_range" | "auth_atom" | "all_atomic">[]]>;
/** `format` parameter values for `*_from_uri` nodes in MVS tree */
export declare const SchemaFormatT: iots.LiteralC<"json" | "cif" | "bcif"> | iots.UnionC<[iots.LiteralC<"json" | "cif" | "bcif">, iots.LiteralC<"json" | "cif" | "bcif">, ...iots.LiteralC<"json" | "cif" | "bcif">[]]>;
/** Parameter values for vector params, e.g. `position` */
export declare const Vector3: iots.TupleC<[iots.NumberC, iots.NumberC, iots.NumberC]>;
/** Parameter values for matrix params, e.g. `rotation` */
export declare const Matrix: iots.ArrayC<iots.NumberC>;
/** `color` parameter values for `color` node in MVS tree */
export declare const HexColorT: iots.Type<HexColor, HexColor, unknown>;
/** `color` parameter values for `color` node in MVS tree */
export declare const ColorNamesT: iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow"> | iots.UnionC<[iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">, iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">, ...iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">[]]>;
/** `color` parameter values for `color` node in MVS tree */
export declare const ColorT: iots.UnionC<[iots.Type<HexColor, HexColor, unknown>, iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow"> | iots.UnionC<[iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">, iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">, ...iots.LiteralC<"black" | "blue" | "cyan" | "gray" | "green" | "magenta" | "orange" | "red" | "white" | "yellow">[]]>]>;
